@@ -181,16 +181,33 @@ def detect_dupl_hashes(names_hashes_list):
 					log.error("Image {0} has a clashing hash {1} ".format(name, hsh))
 
 
+def register_slow_candidates(connection, names_hashes_list):
+	cursor = connection.cursor()
+	for item in names_hashes_list:
+		try:
+			cursor.execute("INSERT INTO candidate_t (name,hash) VALUES (:name,:hash)", item)
+		except sqlite3.IntegrityError as e:
+			connection.rollback()
+			log.warning("Ignoring duplicate candidate in the same dir => %s", item['name'])
+		else:
+			connection.commit()
+
+
 def work_dir_to_session(connection, work_dir, filt):
-	file_list  = glob.glob(os.path.join(work_dir, filt))
+	file_list  = sorted(glob.glob(os.path.join(work_dir, filt)))
 	log.info("Found {0} candidates matching filter {1}.".format(len(file_list), filt))
 	log.info("Computing hashes. This may take a while")
 	names_hashes_list = [ {'name': os.path.basename(p), 'hash': hash(p)} for p in file_list ]
 	detect_dupl_hashes(names_hashes_list)
 	cursor = connection.cursor()
 	cursor.execute("CREATE TEMP TABLE candidate_t (name TEXT, hash BLOB, PRIMARY KEY(hash))")
-	cursor.executemany("INSERT INTO candidate_t (name,hash) VALUES (:name,:hash)", names_hashes_list)
-	connection.commit()
+	try:
+		cursor.executemany("INSERT INTO candidate_t (name,hash) VALUES (:name,:hash)", names_hashes_list)
+	except sqlite3.IntegrityError as e:
+		connection.rollback()
+		register_slow_candidates(connection, names_hashes_list)
+	else:
+		connection.commit()
 	# Common images to database and work-dir
 	cursor.execute(
 		'''
@@ -393,6 +410,7 @@ def register_log_kept(connection, session):
 			SELECT name
 			FROM image_t
 			WHERE hash IN (SELECT hash FROM candidate_t)
+			ORDER BY name ASC
 			LIMIT :count
 			''', row)
 		for name, in cursor:
@@ -521,14 +539,28 @@ def stats_session_iterable(connection, session):
 		FROM image_t
 		WHERE state < :state
 		AND session = :session
+		ORDER BY name ASC
 		''', row)
 	return cursor
 
 
+def stats_unregister(connection, rows):
+	'''Unregister an image who gave an exception reaing the pixel data'''
+	cursor = connection.cursor()
+	cursor.executemany(
+			'''
+			DELETE FROM image_t 
+			WHERE hash  == :hash
+			''', rows)
+	connection.commit()
+	log.info("Deleted %d / %d images from database", cursor.rowcount, len(rows))
+	
+
 def do_stats(connection, session, work_dir, options):
 	stats_computed_flag = False
 	camera_cache = CameraCache(options.camera)
 	rows = []
+	rows_to_unregister = []
 	counter = LogCounter(N_COUNT)
 	CameraImage.ExiftoolFixed = False
 	log.debug("Computing image statistics")
@@ -538,19 +570,26 @@ def do_stats(connection, session, work_dir, options):
 		image.setROI(options.roi)
 		counter.tick("Statistics for %03d images done")
 		metadata = image.loadEXIF()
-		image.read()
-		row = image.stats()
-		row['hash']         = hsh
-		row['state']        = STATS_COMPUTED
-		row['model']        = metadata['model']
-		row['iso']          = metadata['iso']
-		row['tstamp']       = metadata['tstamp']
-		row['night']        = metadata['night']
-		row['exptime']      = metadata['exptime']
-		row['bias']         = metadata['bias']
-		row['focal_length'] = metadata['focal_length']
-		row['f_number']     = metadata['f_number']
-		rows.append(row)
+		try:
+			image.read()
+		except Exception as e:
+			log.warn("%s: Error while reading pixels", name)
+			rows_to_unregister.append({'name': name, 'hash': hsh, 'session':session})
+		else:
+			row = image.stats()
+			row['hash']         = hsh
+			row['state']        = STATS_COMPUTED
+			row['model']        = metadata['model']
+			row['iso']          = metadata['iso']
+			row['tstamp']       = metadata['tstamp']
+			row['night']        = metadata['night']
+			row['exptime']      = metadata['exptime']
+			row['bias']         = metadata['bias']
+			row['focal_length'] = metadata['focal_length']
+			row['f_number']     = metadata['f_number']
+			rows.append(row)
+	if rows_to_unregister:
+		stats_unregister(connection, rows_to_unregister)
 	if rows:
 		counter.end("Statistics for %03d images done")
 		stats_update_db(connection, rows)
@@ -593,6 +632,8 @@ def do_metadata(connection, session, options):
 		UPDATE image_t 
 		SET 
 			observer     = :observer,
+			obs_family_name = :obs_family_name,
+			obs_surname  = :obs_surname,
 			organization = :organization,
 			email        = :email,
 			location     = :location
@@ -1469,12 +1510,12 @@ def do_image_reduce(connection, options):
 
 def do_image_multidir_reduce(connection, options):
 	with os.scandir(options.work_dir) as it:
-		dirs  = [ entry.path for entry in it if entry.is_dir() ]
+		dirs  = [ entry.path for entry in it if entry.is_dir()  ]
 		files = [ entry.path for entry in it if entry.is_file() ]
 	if dirs:
 		if files:
 			log.warning("Ignoring files in %s", options.work_dir)
-		for item in dirs:
+		for item in sorted(dirs, reverse=True):
 			options.work_dir = item
 			try:
 				do_image_reduce(connection, options)
@@ -1486,6 +1527,10 @@ def do_image_multidir_reduce(connection, options):
 
 
 def image_reduce(connection, options):
+	
+	def by_name(item):
+		return item[0]
+
 	if not options.multiuser:
 		do_image_multidir_reduce(connection, options)
 	else:
@@ -1493,7 +1538,7 @@ def image_reduce(connection, options):
 		with os.scandir(options.work_dir) as it:
 			dirs = [ (entry.name, entry.path) for entry in it if entry.is_dir() ]
 		if dirs:
-			for key, path in dirs:
+			for key, path in sorted(dirs, key=by_name):
 				options.config   = os.path.join(AZOTEA_CFG_DIR, key + '.ini')
 				options.work_dir = path
 				try:
